package core.notevault.ui.gallery;

import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageButton;
import android.widget.TextView;
import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;
import core.notevault.R;
import core.notevault.data.Concert;
import core.notevault.ui.home.NoteSongAdapter;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;

public class ConcertAdapter extends RecyclerView.Adapter<ConcertAdapter.ConcertViewHolder> {

    private final List<Concert> concertList;
    private final OnConcertDeleteListener deleteListener;
    private final OnOpenConcertEditorListener editorListener;

    public interface OnConcertDeleteListener {
        void onDeleteConcert(Concert concert);
    }

    public interface OnOpenConcertEditorListener {
        void onOpenConcertEditor(Concert concert);
    }

    public ConcertAdapter(List<Concert> concertList, OnConcertDeleteListener deleteListener, OnOpenConcertEditorListener editorListener) {
        this.concertList = concertList;
        this.deleteListener = deleteListener;
        this.editorListener = editorListener;
    }

    public ConcertAdapter(OnConcertDeleteListener deleteListener, OnOpenConcertEditorListener editorListener) {
        this.deleteListener = deleteListener;
        this.editorListener = editorListener;
        this.concertList = new ArrayList<>();
    }

    @Override
    public void onBindViewHolder(@NonNull ConcertViewHolder holder, int position) {
        holder.concertTitleView.setText(concertList.get(position).getTitle());
        holder.dateHolder.setText(concertList.get(position).getConcertDate());

        holder.deleteButton.setOnClickListener(v -> deleteListener.onDeleteConcert(concertList.get(position)));
        holder.editButton.setOnClickListener(v -> editorListener.onOpenConcertEditor(concertList.get(position)));

    }

    @Override
    public int getItemCount() {
        return concertList.size();
    }

    @NonNull
    @Override
    public ConcertViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.concert_item, parent, false);
        return new ConcertViewHolder(view);
    }

    public void updateConcerts(List<Concert> concerts) {
        Log.d("ConcertAdapter", "Update Concerts: " + this.concertList.size() + "vs new: " + concerts.size());
        this.concertList.clear();
        this.concertList.addAll(concerts);
        notifyDataSetChanged();
    }

    public class ConcertViewHolder extends RecyclerView.ViewHolder {
        TextView concertTitleView;
        TextView dateHolder;

        ImageButton deleteButton;
        ImageButton editButton;

        public ConcertViewHolder(@NonNull @NotNull View itemView) {
            super(itemView);
            concertTitleView = itemView.findViewById(R.id.concert_title);
            dateHolder = itemView.findViewById(R.id.concert_date);
            deleteButton = itemView.findViewById(R.id.delete_concert_button);
            editButton = itemView.findViewById(R.id.edit_concert_button);
        }
    }
}
